Django Endless Pagination can be used to provide Twitter-style or
Digg-style pagination, with optional Ajax support and other features
like multiple or lazy pagination.

The initial idea, which has guided the development of this application,
is to allow pagination of web contents in `very few steps
<http://django-endless-pagination.readthedocs.org/en/latest/start.html>`_.

**Documentation** is `avaliable online
<http://django-endless-pagination.readthedocs.org/>`_, or in the docs
directory of the project.

To file **bugs and requests**, please use
https://github.com/frankban/django-endless-pagination/issues.

The **source code** for this app is hosted at
https://github.com/frankban/django-endless-pagination.

The **Mercurial repository** of this project is hosted at
https://bitbucket.org/frankban/django-endless-pagination.
